aboutsummaryrefslogtreecommitdiff
path: root/base/android/apk_assets.h
diff options
context:
space:
mode:
Diffstat (limited to 'base/android/apk_assets.h')
-rw-r--r--base/android/apk_assets.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/base/android/apk_assets.h b/base/android/apk_assets.h
index 6eb5da3..cdac000 100644
--- a/base/android/apk_assets.h
+++ b/base/android/apk_assets.h
@@ -8,14 +8,12 @@
#include <string>
#include "base/android/jni_android.h"
+#include "base/files/file_path.h"
#include "base/files/memory_mapped_file.h"
-#include "base/posix/global_descriptors.h"
namespace base {
namespace android {
-bool RegisterApkAssets(JNIEnv* env);
-
// Opens an asset (e.g. a .pak file) from the apk.
// Can be used from renderer process.
// Fails if the asset is not stored uncompressed within the .apk.
@@ -28,11 +26,12 @@ BASE_EXPORT int OpenApkAsset(
const std::string& file_path,
base::MemoryMappedFile::Region* region);
// Registers an uncompressed asset from within the apk with GlobalDescriptors.
// Returns: true in case of success, false otherwise.
-BASE_EXPORT bool RegisterApkAssetWithGlobalDescriptors(
- base::GlobalDescriptors::Key key,
- const std::string& file_path);
+BASE_EXPORT bool RegisterApkAssetWithFileDescriptorStore(
+ const std::string& key,
+ const base::FilePath& file_path);
} // namespace android
} // namespace base
@@ -28,11 +26,12 @@ BASE_EXPORT int OpenApkAsset(
const std::string& file_path,
base::MemoryMappedFile::Region* region);
-// Registers an uncompressed asset from within the apk with GlobalDescriptors.
+// Registers an uncompressed asset from within the apk in the
+// FileDescriptorStore.
// Returns: true in case of success, false otherwise.